import { Link } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faServer, faProjectDiagram, faCode } from '@fortawesome/free-solid-svg-icons';

const icons = {
  "devops-sre": faServer,
  "non-technical-tech": faProjectDiagram,
  "development": faCode
};

const FeaturedRoadmaps = ({ roadmaps }) => (
  <div className="container mx-auto px-6 py-12">
    <div className="text-center mb-16">
      <h2 className="text-3xl md:text-4xl font-bold mb-4">Featured Roadmaps</h2>
      <p className="text-lg text-gray-300 max-w-2xl mx-auto">
        Choose your tech path and follow our step-by-step guidance to build your career
      </p>
    </div>
    
    <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
      {roadmaps.map((roadmap, index) => (
        <Link 
          key={index} 
          to={`/roadmap/${roadmap.id}`} 
          className="feature-card bg-dark-700 rounded-xl shadow-lg overflow-hidden hover:shadow-xl transition-all duration-300"
        >
          <div className="p-1 bg-gradient-to-r from-primary-500 to-secondary-500">
            <div className="bg-dark-700 p-8 rounded-t-xl">
              <div className="flex justify-center items-center w-16 h-16 mx-auto mb-6 rounded-full bg-dark-800 text-primary-500">
                <FontAwesomeIcon icon={icons[roadmap.id]} className="text-3xl" />
              </div>
              <h3 className="text-2xl font-bold text-center mb-3">{roadmap.title}</h3>
              <p className="text-gray-400 text-center mb-4">{roadmap.description}</p>
              <div className="mt-6 flex justify-center">
                <span className="inline-flex items-center text-primary-400 font-medium">
                  Explore roadmap 
                  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 ml-1" viewBox="0 0 20 20" fill="currentColor">
                    <path fillRule="evenodd" d="M12.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-2.293-2.293a1 1 0 010-1.414z" clipRule="evenodd" />
                  </svg>
                </span>
              </div>
            </div>
          </div>
          <div className="px-8 py-4 bg-dark-600 text-center">
            <div className="flex justify-center space-x-2">
              {['Beginner', 'Intermediate', 'Advanced'].map((level, i) => (
                <span 
                  key={i} 
                  className={`text-xs px-2 py-1 rounded-full ${
                    i === 0 ? 'bg-primary-500/20 text-primary-300' : 
                    'bg-dark-500 text-gray-400'
                  }`}
                >
                  {level}
                </span>
              ))}
            </div>
          </div>
        </Link>
      ))}
    </div>
    
    <div className="mt-12 text-center">
      <Link 
        to="/roadmap" 
        className="inline-flex items-center px-6 py-3 bg-dark-700 hover:bg-dark-600 text-white font-medium rounded-lg transition-colors duration-300"
      >
        View All Roadmaps
        <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 ml-2" viewBox="0 0 20 20" fill="currentColor">
          <path fillRule="evenodd" d="M10.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L12.586 11H5a1 1 0 110-2h7.586l-2.293-2.293a1 1 0 010-1.414z" clipRule="evenodd" />
        </svg>
      </Link>
    </div>
  </div>
);

export default FeaturedRoadmaps;